@@ -12,11 +12,11 @@ from energinetml.azure.datasets import (
 )
 from energinetml.azure.logger import AzureMlLogger
 from energinetml.core.logger import ConsoleLogger
-from energinetml.core.model import Model, TrainedModel
 from energinetml.core.training import AbstractTrainingContext
 
 if TYPE_CHECKING:
     from energinetml.azure.backend import AzureBackend
+    from energinetml.core.model import Model, TrainedModel
 
 
 class AzureLocalTrainingContext(AbstractTrainingContext):
@@ -33,7 +33,9 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
         self.force_download = force_download
         self.az_run = None
 
-    def train_model(self, model: Model, tags: Dict[str, Any], **kwargs) -> TrainedModel:
+    def train_model(
+        self, model: "Model", tags: Dict[str, Any], **kwargs
+    ) -> "TrainedModel":
         """[summary]
 
         Args:
@@ -85,7 +87,7 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
                 except azureml._common.exceptions.AzureMLException as ex:
                     raise self.backend.parse_azureml_exception(ex)
 
-    def save_output_files(self, model: Model):
+    def save_output_files(self, model: "Model"):
         """[summary]
 
         Args:
@@ -129,7 +131,7 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
         except azureml._common.exceptions.AzureMLException as ex:
             raise self.backend.parse_azureml_exception(ex)
 
-    def get_parameters(self, model: Model) -> Dict:
+    def get_parameters(self, model: "Model") -> Dict:
         """[summary]
 
         Args:
@@ -143,7 +145,7 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
         params.update(model.parameters_local)
         return params
 
-    def get_tags(self, model: Model) -> Dict:
+    def get_tags(self, model: "Model") -> Dict:
         """[summary]
 
         Args:
@@ -161,7 +163,9 @@ class AzureCloudTrainingContext(AbstractTrainingContext):
     def __init__(self):
         self.az_run = None
 
-    def train_model(self, model: Model, tags: Dict[str, Any], **kwargs) -> TrainedModel:
+    def train_model(
+        self, model: "Model", tags: Dict[str, Any], **kwargs
+    ) -> "TrainedModel":
         """[summary]
 
         Args:
@@ -195,7 +199,7 @@ class AzureCloudTrainingContext(AbstractTrainingContext):
         """
         return self.az_run.get_portal_url()
 
-    def get_parameters(self, model: Model) -> Dict:
+    def get_parameters(self, model: "Model") -> Dict:
         """[summary]
 
         Args:
@@ -209,7 +213,7 @@ class AzureCloudTrainingContext(AbstractTrainingContext):
         params.update(model.parameters_cloud)
         return params
 
-    def get_tags(self, model: Model) -> Dict:
+    def get_tags(self, model: "Model") -> Dict:
         """[summary]
 
         Args:
