@@ -1,27 +1,27 @@
-import pytest
 import tempfile
 
+import pytest
+
 from energinetml.core.model import Model
 from energinetml.core.project import MachineLearningProject
 
-
 # Project
-PROJECT_NAME = 'NAME'
-SUBSCRIPTION_ID = 'SUBSCRIPTION-ID'
-RESOURCE_GROUP = 'RESOURCE-GROUP'
-WORKSPACE_NAME = 'WORKSPACE-NAME'
-VNET = 'VNET'
-SUBNET = 'SUBNET'
+PROJECT_NAME = "NAME"
+SUBSCRIPTION_ID = "SUBSCRIPTION-ID"
+RESOURCE_GROUP = "RESOURCE-GROUP"
+WORKSPACE_NAME = "WORKSPACE-NAME"
+VNET = "VNET"
+SUBNET = "SUBNET"
 
 
 # Model
-MODEL_NAME = 'NAME'
-EXPERIMENT = 'EXPERIMENT'
-COMPUTE_TARGET = 'COMPUTE-TARGET'
-VM_SIZE = 'VM-SIZE'
-DATASETS = ['iris', 'hades:2']
-FEATURES = ['feature1', 'feature2']
-PARAMETERS = {'param1': 'value1', 'param2': 'value2'}
+MODEL_NAME = "NAME"
+EXPERIMENT = "EXPERIMENT"
+COMPUTE_TARGET = "COMPUTE-TARGET"
+VM_SIZE = "VM-SIZE"
+DATASETS = ["iris", "hades:2"]
+FEATURES = ["feature1", "feature2"]
+PARAMETERS = {"param1": "value1", "param2": "value2"}
 
 
 @pytest.fixture
@@ -84,16 +84,16 @@ def pytest_addoption(parser):
     Adds command-line options to "pytest" command which will
     become available when running tests. Used for smoke testing.
     """
-    parser.addoption('--path', action='store', default=None)
-    parser.addoption('--subscription-id', action='store', default=None)
-    parser.addoption('--subscription-name', action='store', default=None)
-    parser.addoption('--resource-group', action='store', default=None)
-    parser.addoption('--service-connection', action='store', default=None)
-    parser.addoption('--workspace-name', action='store', default=None)
-    parser.addoption('--project-name', action='store', default=None)
-    parser.addoption('--model-name', action='store', default=None)
-    parser.addoption('--deployment-base-url', action='store', default=None)
-    parser.addoption('--sdk-version', action='store', default=None)
+    parser.addoption("--path", action="store", default=None)
+    parser.addoption("--subscription-id", action="store", default=None)
+    parser.addoption("--subscription-name", action="store", default=None)
+    parser.addoption("--resource-group", action="store", default=None)
+    parser.addoption("--service-connection", action="store", default=None)
+    parser.addoption("--workspace-name", action="store", default=None)
+    parser.addoption("--project-name", action="store", default=None)
+    parser.addoption("--model-name", action="store", default=None)
+    parser.addoption("--deployment-base-url", action="store", default=None)
+    parser.addoption("--sdk-version", action="store", default=None)
 
 
 @pytest.fixture
@@ -101,7 +101,7 @@ def path(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--path')
+    return pytestconfig.getoption("--path")
 
 
 @pytest.fixture
@@ -109,7 +109,7 @@ def subscription_id(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--subscription-id')
+    return pytestconfig.getoption("--subscription-id")
 
 
 @pytest.fixture
@@ -117,7 +117,7 @@ def subscription_name(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--subscription-name')
+    return pytestconfig.getoption("--subscription-name")
 
 
 @pytest.fixture
@@ -125,7 +125,7 @@ def resource_group(pytestconfig):
     """
     Used by ML AND Web-App smoketests.
     """
-    return pytestconfig.getoption('--resource-group')
+    return pytestconfig.getoption("--resource-group")
 
 
 @pytest.fixture
@@ -133,7 +133,7 @@ def service_connection(pytestconfig):
     """
     Used by Web-App smoketests.
     """
-    return pytestconfig.getoption('--service-connection')
+    return pytestconfig.getoption("--service-connection")
 
 
 @pytest.fixture
@@ -141,7 +141,7 @@ def workspace_name(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--workspace-name')
+    return pytestconfig.getoption("--workspace-name")
 
 
 @pytest.fixture
@@ -149,7 +149,7 @@ def project_name(pytestconfig):
     """
     Used by ML AND Web-App smoketests.
     """
-    return pytestconfig.getoption('--project-name')
+    return pytestconfig.getoption("--project-name")
 
 
 @pytest.fixture
@@ -157,7 +157,7 @@ def model_name(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--model-name')
+    return pytestconfig.getoption("--model-name")
 
 
 @pytest.fixture
@@ -165,7 +165,7 @@ def deployment_base_url(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--deployment-base-url')
+    return pytestconfig.getoption("--deployment-base-url")
 
 
 @pytest.fixture
@@ -173,7 +173,7 @@ def sdk_version(pytestconfig):
     """
     Used by ML smoketests.
     """
-    return pytestconfig.getoption('--sdk-version')
+    return pytestconfig.getoption("--sdk-version")
 
 
 @pytest.fixture
@@ -181,12 +181,7 @@ def prediction_input():
     """
     Used by ML smoketests.
     """
-    return {
-        'inputs': [
-            {'features': {'age': 20}},
-            {'features': {'age': 40}}
-        ],
-    }
+    return {"inputs": [{"features": {"age": 20}}, {"features": {"age": 40}}]}
 
 
 @pytest.fixture
@@ -194,4 +189,4 @@ def prediction_output():
     """
     Used by ML smoketests.
     """
-    return ['no', 'yes']
+    return ["no", "yes"]
